@@ -30,17 +30,26 @@
 
 #include <KIO/CopyJob>
 #include <KIO/DeleteJob>
+#include <kio_version.h>
+#if KIO_VERSION >= QT_VERSION_CHECK(5, 98, 0)
+#include <KIO/JobUiDelegateFactory>
+#endif
 #include <KIO/JobUiDelegate>
 #include <KIO/OpenFileManagerWindowJob>
 #include <KIO/OpenUrlJob>
-#include <kio_version.h>
+#if KIO_VERSION >= QT_VERSION_CHECK(5, 100, 0)
+#include <KIO/DeleteOrTrashJob>
+#endif
 
 // Permission strings
-static const char *const perm[4] = {
-    I18N_NOOP("Read-write"),
-    I18N_NOOP("Read-only"),
-    I18N_NOOP("Write-only"),
-    I18N_NOOP("Inaccessible")
+#include <ki18n_version.h>
+#include <KLazyLocalizedString>
+
+const KLazyLocalizedString perm[4] = {
+    kli18n("Read-write"),
+    kli18n("Read-only"),
+    kli18n("Write-only"),
+    kli18n("Inaccessible")
 };
 #define RW 0
 #define RO 1
@@ -78,19 +87,14 @@ QVariant KFindItemModel::headerData(int section, Qt::Orientation orientation, in
     return QVariant();
 }
 
-void KFindItemModel::insertFileItems(const QList< QPair<KFileItem, QString> > &pairs)
+void KFindItemModel::insertFileItems(const QList<QPair<KFileItem, QString>> &pairs)
 {
     if (!pairs.isEmpty()) {
         beginInsertRows(QModelIndex(), m_itemList.size(), m_itemList.size()+pairs.size()-1);
 
-        QList< QPair<KFileItem, QString> >::const_iterator it = pairs.constBegin();
-        QList< QPair<KFileItem, QString> >::const_iterator end = pairs.constEnd();
-
-        for (; it != end; ++it) {
-            QPair<KFileItem, QString> pair = *it;
-
-            const QString subDir = m_view->reducedDir(pair.first.url().adjusted(QUrl::RemoveFilename).path());
-            m_itemList.append(KFindItem(pair.first, subDir, pair.second));
+        for (const auto &[item, dir] : pairs) {
+            const QString subDir = m_view->reducedDir(item.url().adjusted(QUrl::RemoveFilename).path());
+            m_itemList.append(KFindItem(item, subDir, dir));
         }
 
         endInsertRows();
@@ -238,8 +242,7 @@ KFindItem::KFindItem(const KFileItem &_fileItem, const QString &subDir, const QS
         } else {
             perm_index = fileInfo.isWritable() ? WO : NA;
         }
-
-        m_permission = i18n(perm[perm_index]);
+        m_permission = KLocalizedString(perm[perm_index]).toString();
 
         m_icon = QIcon::fromTheme(m_fileItem.iconName());
     }
@@ -513,7 +516,11 @@ void KFindTreeView::saveResults()
                            i18n("Unable to save results."));
     } else {
         QTextStream stream(&file);
+        #if QT_VERSION >= QT_VERSION_CHECK(6, 0, 0)
+        stream.setEncoding(QStringConverter::System);
+        #else
         stream.setCodec(QTextCodec::codecForLocale());
+        #endif
 
         const QList<KFindItem> itemList = m_model->getItemList();
         if (dialog.selectedMimeTypeFilter() == QLatin1String("text/html")) {
@@ -561,7 +568,11 @@ void KFindTreeView::slotExecuteSelected()
             KFindItem item = m_model->itemAtIndex(index);
             if (item.isValid()) {
                 auto *job = new KIO::OpenUrlJob(item.getFileItem().targetUrl());
+#if KIO_VERSION >= QT_VERSION_CHECK(5, 98, 0)
+                job->setUiDelegate(KIO::createDefaultJobUiDelegate(KJobUiDelegate::AutoHandlingEnabled, this));
+#else
                 job->setUiDelegate(new KIO::JobUiDelegate(KJobUiDelegate::AutoHandlingEnabled, this));
+#endif
                 job->start();
             }
         }
@@ -583,7 +594,11 @@ void KFindTreeView::slotExecute(const QModelIndex &index)
         const KFindItem item = m_model->itemAtIndex(realIndex);
         if (item.isValid()) {
             auto *job = new KIO::OpenUrlJob(item.getFileItem().targetUrl());
+#if KIO_VERSION >= QT_VERSION_CHECK(5, 98, 0)
+            job->setUiDelegate(KIO::createDefaultJobUiDelegate(KJobUiDelegate::AutoHandlingEnabled, this));
+#else
             job->setUiDelegate(new KIO::JobUiDelegate(KJobUiDelegate::AutoHandlingEnabled, this));
+#endif
             job->start();
         }
     }
@@ -663,6 +678,7 @@ void KFindTreeView::deleteSelectedFiles()
         return;
     }
 
+#if KIO_VERSION < QT_VERSION_CHECK(5, 100, 0)
     KIO::JobUiDelegate uiDelegate;
     uiDelegate.setWindow(this);
     if (uiDelegate.askDeleteConfirmation(uris, KIO::JobUiDelegate::Delete, KIO::JobUiDelegate::ForceConfirmation)) {
@@ -670,6 +686,11 @@ void KFindTreeView::deleteSelectedFiles()
         KJobWidgets::setWindow(deleteJob, this);
         deleteJob->uiDelegate()->setAutoErrorHandlingEnabled(true);
     }
+#else
+    using Iface = KIO::AskUserActionInterface;
+    auto *trashJob = new KIO::DeleteOrTrashJob(uris, Iface::Delete, Iface::ForceConfirmation, this);
+    trashJob->start();
+#endif
 }
 
 void KFindTreeView::moveToTrashSelectedFiles()
@@ -679,6 +700,7 @@ void KFindTreeView::moveToTrashSelectedFiles()
         return;
     }
 
+#if KIO_VERSION < QT_VERSION_CHECK(5, 100, 0)
     KIO::JobUiDelegate uiDelegate;
     uiDelegate.setWindow(this);
     if (uiDelegate.askDeleteConfirmation(uris, KIO::JobUiDelegate::Trash, KIO::JobUiDelegate::ForceConfirmation)) {
@@ -686,6 +708,11 @@ void KFindTreeView::moveToTrashSelectedFiles()
         KJobWidgets::setWindow(trashJob, this);
         trashJob->uiDelegate()->setAutoErrorHandlingEnabled(true);
     }
+#else
+    using Iface = KIO::AskUserActionInterface;
+    auto *trashJob = new KIO::DeleteOrTrashJob(uris, Iface::Trash, Iface::ForceConfirmation, this);
+    trashJob->start();
+#endif
 }
 
 void KFindTreeView::reconfigureMouseSettings()
